Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FileExists ¶
FileExists returns true if the filename path exists or false if not
func MultiSymbolProcessor ¶
func MultiSymbolProcessor(commentSymbols []string, line *dialect.DialectLine)
MultiSymbolProcessor can be used when you have more than one symbol which designates the line is a comment
func SingleSymbolProcessor ¶
func SingleSymbolProcessor(commentSymbol string, line *dialect.DialectLine)
SingleSymbolProcessor can be used when you only have a single symbol which designates the line is a comment
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.