copyright

package
v0.0.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 13, 2017 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type CopyrightResult

type CopyrightResult struct {
	Found bool
	Dates []string
	Name  string
}

func ParseCopyright

func ParseCopyright(line string) (*CopyrightResult, error)

ParseCopyright will attempt to parse copyright details from a line (if found)

func (*CopyrightResult) HTMLString

func (c *CopyrightResult) HTMLString() string

provides a nice string representation of the Copyright statement

func (*CopyrightResult) String

func (c *CopyrightResult) String() string

provides a nice string representation of the Copyright statement

func (*CopyrightResult) Stringify

func (c *CopyrightResult) Stringify(symbol string) string

Jump to