implementation

package
v0.0.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 13, 2017 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func New

func New() types.Dialect

New returns a new implementation of Dialect

Types

type DialectImplementation

type DialectImplementation struct {
}

func (*DialectImplementation) CreateLineByLineExaminer

func (i *DialectImplementation) CreateLineByLineExaminer(language string, filename string, config *types.DialectConfiguration) (*types.DialectContext, error)

CreateLineByLineExaminer returns an interface which can be called with each line using the ProcessLine function

func (*DialectImplementation) DetectFrameworks

func (i *DialectImplementation) DetectFrameworks(directory string) ([]*types.DialectFramework, error)

Detect will attempt to detect all the frameworks for a given project source directory

func (*DialectImplementation) Examine

func (i *DialectImplementation) Examine(language string, filename string, reader io.Reader, config *types.DialectConfiguration) (*types.DialectResult, error)

Examine is used to detect information about the source code

Jump to