Documentation
¶
Index ¶
- Variables
- func CreateConfigurationWithCallback(callback types.DialectResultCallback) *types.DialectConfiguration
- func CreateDefaultConfiguration() *types.DialectConfiguration
- func CreateLineByLineExaminer(language string, filename string, config *types.DialectConfiguration) (*types.DialectContext, error)
- func DetectFrameworks(directory string) ([]*types.DialectFramework, error)
- func Examine(language string, filename string, reader io.Reader, ...) (*types.DialectResult, error)
Constants ¶
This section is empty.
Variables ¶
var ( Build string Version string )
Functions ¶
func CreateConfigurationWithCallback ¶
func CreateConfigurationWithCallback(callback types.DialectResultCallback) *types.DialectConfiguration
CreateConfigurationWithCallback returns a default configuration with a callback
func CreateDefaultConfiguration ¶
func CreateDefaultConfiguration() *types.DialectConfiguration
CreateDefaultConfiguration will return a default configuration
func CreateLineByLineExaminer ¶
func CreateLineByLineExaminer(language string, filename string, config *types.DialectConfiguration) (*types.DialectContext, error)
CreateLineByLineExaminer returns an interface which can be called with each line using the ProcessLine function
func DetectFrameworks ¶
func DetectFrameworks(directory string) ([]*types.DialectFramework, error)
Detect will attempt to detect all the frameworks for a given project source directory
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.