Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CopyrightResult ¶
func ParseCopyright ¶
func ParseCopyright(line string) (*CopyrightResult, error)
ParseCopyright will attempt to parse copyright details from a line (if found)
func (*CopyrightResult) HTMLString ¶
func (c *CopyrightResult) HTMLString() string
provides a nice string representation of the Copyright statement
func (*CopyrightResult) String ¶
func (c *CopyrightResult) String() string
provides a nice string representation of the Copyright statement
func (*CopyrightResult) Stringify ¶
func (c *CopyrightResult) Stringify(symbol string) string
Click to show internal directories.
Click to hide internal directories.