Documentation
¶
Index ¶
- func New() types.Dialect
- type DialectImplementation
- func (i *DialectImplementation) CreateLineByLineExaminer(language string, filename string, config *types.DialectConfiguration) (*types.DialectContext, error)
- func (i *DialectImplementation) DetectFrameworks(directory string) ([]*types.DialectFramework, error)
- func (i *DialectImplementation) Examine(language string, filename string, reader io.Reader, ...) (*types.DialectResult, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type DialectImplementation ¶
type DialectImplementation struct {
}
func (*DialectImplementation) CreateLineByLineExaminer ¶
func (i *DialectImplementation) CreateLineByLineExaminer(language string, filename string, config *types.DialectConfiguration) (*types.DialectContext, error)
CreateLineByLineExaminer returns an interface which can be called with each line using the ProcessLine function
func (*DialectImplementation) DetectFrameworks ¶
func (i *DialectImplementation) DetectFrameworks(directory string) ([]*types.DialectFramework, error)
Detect will attempt to detect all the frameworks for a given project source directory
func (*DialectImplementation) Examine ¶
func (i *DialectImplementation) Examine(language string, filename string, reader io.Reader, config *types.DialectConfiguration) (*types.DialectResult, error)
Examine is used to detect information about the source code
Click to show internal directories.
Click to hide internal directories.